.. role:: hidden
    :class: hidden-section

ax.global_stopping
==================

.. automodule:: ax.global_stopping
.. currentmodule:: ax.global_stopping

Strategies
----------

Base Strategies
~~~~~~~~~~~~~~~

.. automodule:: ax.global_stopping.strategies.base
    :members:
    :undoc-members:
    :show-inheritance:

`ImprovementGlobalStoppingStrategy`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.global_stopping.strategies.improvement
    :members:
    :undoc-members:
    :show-inheritance:
